@@ -160,13 +160,14 @@ namespace Tomboy
 			}
 		}
 
+		//Text is actually an Xml formatted string
 		public string Text
 		{
 			get {
 				SynchronizeText ();
 				return data.Text;
 			}
-			set { 
+			set {
 				data.Text = value;
 				SynchronizeBuffer ();
 			}
@@ -463,7 +464,12 @@ namespace Tomboy
 		public string XmlContent 
 		{
 			get { return data.Text; }
-			set { data.Text = value; }
+			set { 
+				if (buffer != null)
+					buffer.SetText (XmlDecoder.Decode (value));
+				else
+					data.Text = value; 
+			}
 		}
 
 		public string TextContent
@@ -476,6 +482,13 @@ namespace Tomboy
 				else 
 					return XmlDecoder.Decode (XmlContent);
 			}
+			set {
+				if (buffer != null)
+					buffer.SetText (value);
+				else
+					Logger.Log ("Setting text content for closed notes not supported");
+			}
+				
 		}
 
 		public NoteData Data
@@ -521,6 +534,11 @@ namespace Tomboy
 			}
 		}
 
+		public bool HasBuffer
+		{
+			get { return null != buffer; }
+		}
+
 		public NoteBuffer Buffer
 		{
 			get {
@@ -541,6 +559,11 @@ namespace Tomboy
 			}
 		}
 
+		public bool HasWindow
+		{
+			get { return null != window; }
+		}
+
 		public NoteWindow Window 
 		{
 			get {
@@ -629,6 +652,8 @@ namespace Tomboy
 	public class NoteArchiver
 	{
 		public const string CURRENT_VERSION = "0.2";
+		
+		public const string DATE_TIME_FORMAT = "yyyy-MM-ddTHH:mm:ss.fffffffzzz";
 
 		static NoteArchiver instance = null;
 		static readonly object lock_ = new object();
@@ -688,11 +713,11 @@ namespace Tomboy
 						break;
 					case "last-change-date":
 						note.ChangeDate = 
-							XmlConvert.ToDateTime (xml.ReadString ());
+							XmlConvert.ToDateTime (xml.ReadString (), DATE_TIME_FORMAT);
 						break;
 					case "create-date":
 						note.CreateDate = 
-							XmlConvert.ToDateTime (xml.ReadString ());
+							XmlConvert.ToDateTime (xml.ReadString (), DATE_TIME_FORMAT);
 						break;
 					case "cursor-position":
 						note.CursorPosition = int.Parse (xml.ReadString ());
@@ -800,12 +825,14 @@ namespace Tomboy
 			xml.WriteEndElement ();
 
 			xml.WriteStartElement (null, "last-change-date", null);
-			xml.WriteString (XmlConvert.ToString (note.ChangeDate));
+			xml.WriteString (
+						XmlConvert.ToString (note.ChangeDate, DATE_TIME_FORMAT));
 			xml.WriteEndElement ();
 
 			if (note.CreateDate != DateTime.MinValue) {
 				xml.WriteStartElement (null, "create-date", null);
-				xml.WriteString (XmlConvert.ToString (note.CreateDate));
+				xml.WriteString (
+						XmlConvert.ToString (note.CreateDate, DATE_TIME_FORMAT));
 				xml.WriteEndElement ();
 			}
 
